function varargout=plotIsolines(self,u,varargin)
  p = inputParser; 
  p.KeepUnmatched=true; 
  p.PartialMatching=false;
  p.addParamValue('labels',[]); % select labels to draw
  p.addParamValue('niso',10,@isscalar);
  p.addParamValue('isorange',[]);
  p.addParamValue('isocolorbar',false,@islogical);
  p.addParamValue('plan',false);
  p.addParamValue('color',[]); % unique color
  p.addParamValue('format','%g',@ischar);
  %p.addParamValue('PlotOptions',{});
  p.addParamValue('mouse',true,@islogical);
  p.parse(varargin{:});
  R=p.Results;
  varargin=fc_tools.utils.deleteCellOptions(varargin,p.Parameters);
  if isempty(R.labels), R.labels=self.sThlab(self.sThsimp==2);end
  if isempty(R.labels)
  %  warning('No label found for %d-simplex sub-meshes',2);
    return;
  end
  umin=min(u);umax=max(u);
  if isempty(R.isorange)
    R.isorange=linspace(umin,umax,R.niso);
  else
    R.isorange=sort(R.isorange);
  end
  R.niso=length(R.isorange); 
  if isempty(R.color)
    cmap=colormap();%R.colormap);
    umin=min(umin,R.isorange(1)); % add for partitioned meshes
    umax=max(umax,R.isorange(end));
    t=(R.isorange-umin)/(umax-umin);
    colors = fc_tools.graphics.RGB(t,cmap);
  else
    if ischar(R.color), R.color = fc_tools.graphics.colorstr2rgb(R.color);end
    colors=ones(R.niso,1)*R.color;
  end
  
  LB=self.find(2);
  PrevHold=fc_tools.graphics.SetHoldOn(true);
  set(gcf(),'visible','off')
  for l=1:length(R.labels)
    [I,K]=ismember(R.labels(l),self.sThlab(LB));
    if K~=0
      Ilab=LB(K);
      self.sTh{Ilab}.plotIsolines(u,'niso',R.niso,'isorange',R.isorange,'plan',R.plan, ...
                                  'color',colors,varargin{:});
    end
  end
  if R.isocolorbar
    fc_tools.graphics.colorbarIso(colors,R.isorange,R.format)
  end
  if R.mouse && ~fc_tools.comp.isOctave() % Only Matlab
    datacursormode on
    dcm = datacursormode(gcf);
    set(dcm,'UpdateFcn',@showmeshinfo)
  end
  if nargout>=1, varargout{1}=colors;end
  if nargout==2, varargout{2}=R.isorange;end
  fc_tools.graphics.RestoreHold(PrevHold)
  set(gcf(),'visible','on')
end
